==> pronotepy-1.4.0.tar.gz: pronotepy-1.4.0/pronotepy/__init__.py <==
"""
An API wrapper for pronote.

This whole package is licensed under the MIT license:

Copyright (c) 2020-2021 bain, Xiloe

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"),
to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
"""

__title__ = 'pronotepy'
__author__ = 'bain, Xiloe'
__license__ = 'MIT'
__copyright__ = 'Copyright (c) bain, Xiloe'
__version__ = '1.4.0'

from .dataClasses import Util, Subject, Period, File, Grade, Lesson, Message, LessonContent, ClientInfo, \
    Average, Acquisition, Evaluation, Homework, StudentClass, Student, Identity, Guardian
from .clients import Client, ParentClient, VieScolaireClient
from .exceptions import *

==> pronotepy-2.1.0.tar.gz: pronotepy-2.1.0/pronotepy/__init__.py <==
"""
An API wrapper for pronote.

This whole package is licensed under the MIT license:

Copyright (c) 2020-2021 bain, Xiloe

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"),
to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
"""

__title__ = 'pronotepy'
__author__ = 'bain, Xiloe'
__license__ = 'MIT'
__copyright__ = 'Copyright (c) bain, Xiloe'
__version__ = '2.1.0'

from .dataClasses import Util, Subject, Period, File, Grade, Lesson, Message, LessonContent, Information, ClientInfo, \
    Average, Acquisition, Evaluation, Homework, StudentClass, Student, Identity, Guardian, Object
from .clients import Client, ParentClient, VieScolaireClient
from .exceptions import *
